==> huaweicloudsdkwaf-3.0.54-py2.py3-none-any.whl: huaweicloudsdkwaf/v1/model/delete_premium_host_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeletePremiumHostRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'host_id': 'str',
        'keep_policy': 'bool'
    }

    attribute_map = {
        'host_id': 'host_id',
        'keep_policy': 'keepPolicy'
    }

    def __init__(self, host_id=None, keep_policy=None):
        """DeletePremiumHostRequest - a model defined in huaweicloud sdk"""
        
        

        self._host_id = None
        self._keep_policy = None
        self.discriminator = None

        self.host_id = host_id
        if keep_policy is not None:
            self.keep_policy = keep_policy

    @property
    def host_id(self):
        """Gets the host_id of this DeletePremiumHostRequest.

        独享模式域名ID

        :return: The host_id of this DeletePremiumHostRequest.
        :rtype: str
        """
        return self._host_id

    @host_id.setter
    def host_id(self, host_id):
        """Sets the host_id of this DeletePremiumHostRequest.

        独享模式域名ID

        :param host_id: The host_id of this DeletePremiumHostRequest.
        :type: str
        """
        self._host_id = host_id

    @property
    def keep_policy(self):
        """Gets the keep_policy of this DeletePremiumHostRequest.

        是否保留规则

        :return: The keep_policy of this DeletePremiumHostRequest.
        :rtype: bool
        """
        return self._keep_policy

    @keep_policy.setter
    def keep_policy(self, keep_policy):
        """Sets the keep_policy of this DeletePremiumHostRequest.

        是否保留规则

        :param keep_policy: The keep_policy of this DeletePremiumHostRequest.
        :type: bool
        """
        self._keep_policy = keep_policy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeletePremiumHostRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkwaf-3.0.58-py2.py3-none-any.whl: huaweicloudsdkwaf/v1/model/delete_premium_host_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeletePremiumHostRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'host_id': 'str',
        'keep_policy': 'bool'
    }

    attribute_map = {
        'host_id': 'host_id',
        'keep_policy': 'keepPolicy'
    }

    def __init__(self, host_id=None, keep_policy=None):
        """DeletePremiumHostRequest - a model defined in huaweicloud sdk"""
        
        

        self._host_id = None
        self._keep_policy = None
        self.discriminator = None

        self.host_id = host_id
        if keep_policy is not None:
            self.keep_policy = keep_policy

    @property
    def host_id(self):
        """Gets the host_id of this DeletePremiumHostRequest.

        独享模式域名ID

        :return: The host_id of this DeletePremiumHostRequest.
        :rtype: str
        """
        return self._host_id

    @host_id.setter
    def host_id(self, host_id):
        """Sets the host_id of this DeletePremiumHostRequest.

        独享模式域名ID

        :param host_id: The host_id of this DeletePremiumHostRequest.
        :type: str
        """
        self._host_id = host_id

    @property
    def keep_policy(self):
        """Gets the keep_policy of this DeletePremiumHostRequest.

        是否保留规则

        :return: The keep_policy of this DeletePremiumHostRequest.
        :rtype: bool
        """
        return self._keep_policy

    @keep_policy.setter
    def keep_policy(self, keep_policy):
        """Sets the keep_policy of this DeletePremiumHostRequest.

        是否保留规则

        :param keep_policy: The keep_policy of this DeletePremiumHostRequest.
        :type: bool
        """
        self._keep_policy = keep_policy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeletePremiumHostRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
